@@ -21,7 +21,7 @@ from .lib.helpers.dupedict import DupeDict, JSON
 from .lib.helpers.paths import secure_filename
 
 __author__ = 'Anton Hvornum'
-__version__ = '0.0.20'
+__version__ = '0.0.23'
 __description__ = "Our KVM solution, clulstered and self hosted"
 
 # TODO: https://stackoverflow.com/questions/15889621/sphinx-how-to-exclude-imports-in-automodule
@@ -103,7 +103,8 @@ from .lib.networking import (
 	get_namespaces,
 	curate_interfaces,
 	ifup,
-	InterfaceStruct
+	InterfaceStruct,
+	NamespaceStruct
 )
 from .lib.qemu import (
 	qemu_img,
