@@ -197,7 +197,7 @@ if ourkvm.storage['arguments'].machine_name and \
 	ourkvm.storage['arguments'].network = make_network_processable(ourkvm.storage['arguments'].network)
 
 	ourkvm.verify_qemu_resources(name, base_hardware, pcie_buses, pcie_root_ports, pcie_slave_buses, pcie_slave_devices)
-	network_interfaces = ourkvm.curate_interfaces(ourkvm.storage['arguments'].network, ourkvm.storage['arguments'].namespace)
+	network_interfaces = ourkvm.curate_interfaces([ourkvm.InterfaceStruct(**struct) for struct in ourkvm.storage['arguments'].network], ourkvm.storage['arguments'].namespace)
 
 	service_path = pathlib.Path(f"{ourkvm.storage['arguments'].service}/{name}.service").expanduser().absolute()
 	if service_path.exists() and not ourkvm.storage['arguments'].force:
