@@ -1,4 +1,4 @@
-from typing import Optional
+from typing import Optional, Dict
 
 class RequirementError(BaseException):
 	pass
@@ -24,6 +24,14 @@ class ResourceNotFound(BaseException):
 class ResourceError(BaseException):
 	pass
 
+class ConfigurationError(BaseException):
+	pass
+
+class QMPError(BaseException):
+	def __init__(self, error_obj :Dict[str, str]) -> None:
+		self.type = error_obj.get('class')
+		self.message = error_obj.get('desc')
+
 class SysCallError(BaseException):
 	def __init__(self, message :str, exit_code :Optional[int]) -> None:
 		super(SysCallError, self).__init__(message)
