@@ -2,8 +2,8 @@ from typing import Union, Optional
 from pydantic import BaseModel
 
 class NamespaceStruct(BaseModel):
-	from_: Union[str, bool, None]
-	to: Union[str, bool, None]
+	from_: Union[bool, None, str]
+	to: Union[bool, None, str]
 
 	class Config:
 		# https://github.com/samuelcolvin/pydantic/issues/153
@@ -25,4 +25,5 @@ class InterfaceStruct(BaseModel):
 	namespace: Optional[NamespaceStruct] = None
 	mac: Optional[Union[str, bool]] = None
 	veth_pair: Optional[str] = None
-	bridge: Optional[str] = None
\ No newline at end of file
+	bridge: Optional[str] = None
+	attach: bool = False
\ No newline at end of file
